import React, { memo } from "react";
import { useQuery } from "react-query"; // Optionally installed, so declare as a peer or optional dependency
import { generateUidFromProps } from "src/utils";
import LinkedInIcon from "./LinkedInIcon";
/**
 * Helper function to POST a payload to /api/v2/linkedin/profile/ for React Query usage.
 */
async function fetchLinkedInData(vanity, payloadBodyParams) {
    const response = await fetch(`https://ziping.liu.academy/api/v2/linkedin/profile/?vanity=${vanity}`, {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify(payloadBodyParams),
    });
    if (!response.ok) {
        throw new Error("Failed to fetch LinkedIn profile data with vanity: " + vanity);
    }
    return response.json();
}
const LinkedInBadgeSelfRender = ({ locale = "en_US", size = "medium", style, theme = "light", vanity = "☯liu", version = "v1", className, type = "VERTICAL", entity = "PROFILE", children, generateUidWithoutApi = false, hideViewProfileButton = false, id, TRACKING_PARAM = "public-profile-badge", isCreatePage = false, name = "", noCache = false, debug = false, fetchViaReactQuery = false, // New prop for optional React Query usage
 }) => {
    // Local state for storing the fetched LinkedIn profile data
    const [profileData, setProfileData] = React.useState(null);
    // Local state for storing the unique badge ID
    const [uid, setUid] = React.useState(null);
    /**
     * Decodes \uXXXX strings into the actual Unicode characters.
     * Also used to correct &amp; references in the retrieved data.
     */
    const decodeUnicodeEscapes = React.useCallback((input) => {
        const unicodeEscapeRegex = /\\u([\dA-Fa-f]{4})/g;
        return input.replace(unicodeEscapeRegex, (_match, grp) => String.fromCodePoint(parseInt(grp, 16)));
    }, []);
    /**
     * Helper that builds the payload body params for both XHR or React Query requests.
     * Depends on version, theme, locale, etc.
     */
    const buildPayloadBodyParams = React.useCallback((uidParam, lastUpdatedTime) => {
        const payloadBodyParams = {
            badgetype: encodeURIComponent(type || "VERTICAL"),
            badgetheme: encodeURIComponent(theme || "light"),
            locale: locale || "en_US",
            uid: uidParam || `${lastUpdatedTime ? lastUpdatedTime : new Date().getTime()}`,
            version: encodeURIComponent(version || "v1"),
        };
        // Depending on v1 or v2, different fields are required
        if (version === "v2") {
            payloadBodyParams.badgesize = size || "medium";
            payloadBodyParams.entity = entity || "PROFILE";
        }
        else {
            payloadBodyParams.maxsize = encodeURIComponent(size || "medium");
            payloadBodyParams.trk = TRACKING_PARAM;
            payloadBodyParams.vanityname = encodeURIComponent(vanity || "☯liu");
        }
        if (isCreatePage) {
            payloadBodyParams.fromCreate = "true";
        }
        return payloadBodyParams;
    }, [type, theme, locale, version, size, entity, TRACKING_PARAM, vanity, isCreatePage]);
    /**
     * Optional: If `fetchViaReactQuery` is true, we rely on React Query
     * to fetch data from `/api/v2/linkedin/profile/`.
     */
    const { isLoading, error } = useQuery(["linkedInProfile", vanity, uid], () => fetchLinkedInData(vanity, buildPayloadBodyParams(uid)), {
        // Only enabled if we have a UID (we've generated it) AND the user wants React Query
        enabled: !!uid && fetchViaReactQuery,
        onSuccess: (dataFetched) => {
            if (debug) {
                console.info("Fetched profile data via React Query:", dataFetched);
            }
            // Convert headline’s \u-escapes and &amp;
            let newHeadline = decodeUnicodeEscapes(dataFetched.profileHeadline || "");
            newHeadline = newHeadline.replace(/&amp;/g, "&");
            dataFetched.profileHeadline = newHeadline;
            setProfileData(dataFetched);
            // Optionally store in localStorage if you wish to keep consistent caching
            // localStorage.setItem("...", JSON.stringify(dataFetched));
        },
    });
    /**
     * Effect: (1) Generate the UID, (2) either use React Query or the legacy XHR approach
     * to fetch data if needed, (3) handle local storage caching logic if XHR-based approach is used.
     */
    React.useEffect(() => {
        // First step: Generate a unique ID for the badge
        generateUidFromProps({
            locale,
            size,
            theme,
            type,
            vanity,
            version,
            entity,
            generateUidWithoutApi,
            hideViewProfileButton,
            TRACKING_PARAM,
            isCreatePage,
        }).then((uidNew) => {
            if (uidNew !== uid && uidNew !== null) {
                setUid(uidNew);
            }
            // If React Query is requested, we skip the legacy XHR because useQuery() above handles it.
            if (fetchViaReactQuery) {
                return;
            }
            // *********************** Legacy XHR-based Approach ***********************
            // The following logic is the same as the older code: checks local storage and last-updated time
            const cachedKey = `cachedProfileData-${vanity}-${locale}-${size}-${theme}-${type}-${entity}`;
            const cachedTimeKey = `${cachedKey}-lastUpdated`;
            const cachedProfileData = localStorage.getItem(cachedKey);
            const lastUpdated = localStorage.getItem(cachedTimeKey);
            const now = new Date().getTime();
            const lastUpdatedTime = parseInt(lastUpdated || "0", 10);
            const timeDiff = now - lastUpdatedTime;
            const timeDiffInHours = timeDiff / (1000 * 60 * 60);
            const isCorruptCache = cachedProfileData && !cachedProfileData.includes("profileName");
            const isCacheOutdatedOrMissing = isCorruptCache || !cachedProfileData || !lastUpdated || timeDiffInHours > 48;
            if (debug) {
                console.info("Local cache check:", {
                    cachedProfileData,
                    lastUpdated,
                    isCacheOutdatedOrMissing,
                    timeDiffInHours,
                });
            }
            // If cache is missing or noCache is explicitly set, fetch from server
            if (noCache || isCacheOutdatedOrMissing) {
                if (debug) {
                    console.info("Using XHR approach to fetch fresh data from API");
                }
                // Only fetch if we haven’t already fetched profile data and have a valid UID
                if (profileData === null && uidNew !== null) {
                    const payloadBodyParams = buildPayloadBodyParams(uidNew, lastUpdatedTime);
                    const xhr = new XMLHttpRequest();
                    xhr.open("POST", "https://ziping.liu.academy/api/v2/linkedin/profile/", true);
                    xhr.setRequestHeader("Content-Type", "application/json");
                    xhr.onreadystatechange = function () {
                        // If request is done and status is OK, parse and decode the response
                        if (xhr.readyState === 4 && xhr.status === 200) {
                            const dataParsed = JSON.parse(xhr.responseText);
                            let headlineText = decodeUnicodeEscapes(dataParsed.profileHeadline);
                            headlineText = headlineText.replace(/&amp;/g, "&");
                            dataParsed.profileHeadline = headlineText;
                            if (debug) {
                                console.info("XHR success, storing data in state and localStorage:", dataParsed);
                            }
                            setProfileData(dataParsed);
                            localStorage.setItem(cachedKey, JSON.stringify(dataParsed));
                            localStorage.setItem(cachedTimeKey, new Date().getTime().toString());
                        }
                    };
                    if (debug) {
                        console.info("XHR sending payload:", payloadBodyParams);
                    }
                    xhr.send(JSON.stringify(payloadBodyParams));
                }
            }
            else {
                // Otherwise, load from cache
                if (debug) {
                    console.info("Loading from cache for LinkedIn profile data");
                }
                if (cachedProfileData) {
                    setProfileData(JSON.parse(cachedProfileData));
                }
            }
        });
    }, [
        // Dependencies for effect
        locale,
        size,
        theme,
        type,
        vanity,
        version,
        entity,
        generateUidWithoutApi,
        hideViewProfileButton,
        TRACKING_PARAM,
        isCreatePage,
        noCache,
        debug,
        fetchViaReactQuery,
        buildPayloadBodyParams,
    ]);
    /**
     * Compute width for the badge container based on size and orientation
     */
    const widthSet = React.useMemo(() => {
        const sizeTypeToValueMap = {
            medium: { VERTICAL: "250", HORIZONTAL: "280" },
            large: { VERTICAL: "300", HORIZONTAL: "330" },
        };
        return sizeTypeToValueMap[size][type];
    }, [size, type]);
    if (fetchViaReactQuery && (isLoading || error)) {
        if (isLoading) {
            return React.createElement("div", null, "Loading...");
        }
        if (error) {
            return React.createElement("div", null,
                "Error: ",
                error?.message);
        }
    }
    return (React.createElement("div", { id: id, style: style, className: "profile-badge-reacted" + (className ? ` ${className}` : "") },
        React.createElement("div", { className: `profile-badge profile-badge--width-${widthSet} ` +
                `profile-badge--${theme === "light" ? "light" : "dark"}`, lang: locale?.replace(/_[A-Za-z]+$/, "") || "en", dir: "ltr" },
            React.createElement("div", { className: `profile-badge__header ` +
                    `profile-badge__header--${theme === "light" ? "light" : "dark"}` },
                React.createElement("span", { className: "sr-only" }, "LinkedIn"),
                React.createElement(LinkedInIcon, { theme: theme })),
            React.createElement("div", { className: "profile-badge__content" },
                profileData?.profileImageSrc ? (React.createElement("img", { className: `artdeco-entity-image ` +
                        `artdeco-entity-image--circle-4 ` +
                        `profile-badge__content-profile-image`, title: profileData?.profileName, alt: profileData?.profileName, src: profileData?.profileImageSrc })) : (
                // If no image, show a default SVG
                React.createElement("figure", { title: profileData?.profileName },
                    React.createElement("svg", { className: `artdeco-entity-image ` +
                            `artdeco-entity-image--circle-4 ` +
                            `profile-badge__content-profile-image`, xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 128 128", id: "person-accent-4" },
                        React.createElement("path", { fill: "#e7e2dc", d: "M0 0h128v128H0z" }),
                        React.createElement("path", { d: "M88.41 84.67a32 32 0 10-48.82 0 66.13 66.13 0 0148.82 0z", fill: "#788fa5" }),
                        React.createElement("path", { d: "M88.41 84.67a32 32 0 01-48.82 0A66.79 66.79 0 000 128h128a66.79 66.79 0 00-39.59-43.33z", fill: "#9db3c8" }),
                        React.createElement("path", { d: "M64 96a31.93 31.93 0 0024.41-11.33 66.13 66.13 0 00-48.82 0A31.93 31.93 0 0064 96z", fill: "#56687a" })))),
                React.createElement("h3", { className: "profile-badge__content-profile-name", itemProp: "name" }, profileData?.profileName && (React.createElement("a", { className: `profile-badge__content-profile-name-link ` +
                        `profile-badge__content-profile-name-link--${theme === "light" ? "light" : "dark"}`, href: profileData?.profileNameLink ||
                        "https://www.linkedin.com/in/%E2%98%AFliu?trk=public-profile-badge-profile-badge-profile-name", "data-tracking-control-name": "public-profile-badge-profile-badge-profile-name", "data-tracking-will-navigate": "" }, profileData?.profileName))),
                profileData?.profileHeadline && (React.createElement("h4", { className: "profile-badge__content-profile-headline" }, profileData?.profileHeadline)),
                profileData?.profileCompanyOrSchool && (React.createElement("h4", { className: "profile-badge__content-profile-company-school-info" }, Array.isArray(profileData?.profileCompanyOrSchool) &&
                    profileData?.profileCompanyOrSchool.map((companyOrSchool, index) => (React.createElement("span", { key: `${uid}-company-school-${index}` },
                        React.createElement("a", { target: "_blank", rel: "noopener noreferrer", href: companyOrSchool.href, className: `profile-badge__content-profile-company-school-info-link ` +
                                `profile-badge__content-profile-company-school-info-link--${theme === "light" ? "light" : "dark"}`, "data-tracking-control-name": "public-profile-badge-profile-badge_school-name", "data-tracking-will-navigate": "true" }, companyOrSchool.text),
                        "\u00A0",
                        index !== profileData?.profileCompanyOrSchool.length - 1
                            ? " | "
                            : "",
                        " ",
                        "\u00A0")))))),
            children,
            hideViewProfileButton === false && profileData !== null && (React.createElement("a", { className: `profile-badge__cta-btn ` +
                    `profile-badge__cta-btn--${theme === "light" ? "light" : "dark"}`, rel: "noopener noreferrer", href: profileData?.profileViewLink ||
                    `https://www.linkedin.com/in/${encodeURIComponent(vanity || "☯liu")}?trk=public-profile-badge-profile-badge-profile-cta`, target: "_blank", "data-tracking-control-name": "public-profile-badge-profile-badge-view-profile-cta", "data-tracking-will-navigate": "" }, "View profile")),
            profileData === null && (React.createElement("a", { className: "badge-base__link LI-simple-link", target: "_blank", rel: "noopener noreferrer", key: `${uid}-view-profile-no-data`, href: vanity
                    ? `https://www.linkedin.com/in/${vanity}?trk=profile-badge`
                    : "https://www.linkedin.com/in/%E2%98%AFliu?trk=public-profile-badge-profile-badge-profile-name" }, name)))));
};
export default memo(LinkedInBadgeSelfRender);
