import React, { memo } from "react";
import LinkedInBadgeSelfRender from "./LinkedInBadgeSelfRender";
import LIRender from "./LIRender";
/**
 * React component that renders a LinkedIn badge on a website.
 * @param {LinkedInBadgeProps} props - The props for the LinkedIn badge component, such as the locale, size, theme, type, entity, vanity, version, className, style, children, id, script_src, useLinkedInApiUrlPure, name, debug, and generateUidWithoutApi. See LinkedInBadgeProps for more details.
 * @returns {React.ReactElement} The rendered LinkedIn badge component.
 * @description This implementation uses two React components - LinkedInBadge and LIRenderAll.
 * LinkedInBadge is the parent component responsible for
 * rendering the container and basic structure of the LinkedIn badge,
 * while LIRenderAll is a child component that handles
 * the rendering and management of the actual badge content.
 * @argument The reason for this separation is that the badge content needs to be loaded asynchronously from a server, and the LIRenderAll component is responsible for making the necessary requests and handling the responses. By separating the concerns, the parent component can render the initial structure, and the child component can take care of the dynamic badge content.
 * @example
 * ```tsx
 * <LinkedInBadge
 *    locale="en_US"
 *    size="medium"
 *    theme="light"
 *    type="VERTICAL"
 *    entity="PROFILE"
 *    vanity="☯liu"
 *    version="v1"
 *  />
 * ```
 */
const LinkedInBadge = (props) => {
    const locale = props.locale || "en_US";
    const size = props.size || "medium";
    const theme = props.theme || "light";
    const generateUidWithoutApi = props.generateUidWithoutApi || false;
    const type = props.type || "VERTICAL";
    const entity = props.entity || "PROFILE";
    const vanity = props.vanity || "☯liu";
    const version = props.version || "v1";
    const useLinkedInApiUrlPure = props.useLinkedInApiUrlPure || false;
    const vanityEncoded = encodeURIComponent(vanity);
    const name = props.name || "";
    const noCache = props.noCache || false;
    const useQueryToFetch = props?.useQueryToFetch ?? false;
    const url = `https://www.linkedin.com/in/${vanityEncoded}?trk=profile-badge`;
    const [componentDidMount, setComponentDidMount] = React.useState(false);
    React.useEffect(() => {
        const logDebug = (message, type, componentName) => {
            if (props.debug) {
                const currentTime = new Date().toLocaleTimeString();
                console.log(`[${currentTime}] ${type} - ${componentName}: ${message}`);
            }
        };
        // check if div is rendered via ref
        if (!componentDidMount) {
            logDebug("checking if div is rendered", "info", "at LinkedInBadge Component React.useEffect with componentDidMount: false");
            if (componentDidMount === false) {
                setComponentDidMount(true);
            }
        }
    }, [componentDidMount, props.debug]);
    return useLinkedInApiUrlPure === true ? (React.createElement("div", { className: "badge-base LI-profile-badge" +
            (props.className ? ` ${props.className}` : ""), style: props.style, "data-locale": locale, "data-size": size, "data-theme": theme, "data-type": type, "data-vanity": vanity, "data-version": version, "data-rendered": "false", id: props.id },
        React.createElement("a", { className: "badge-base__link LI-simple-link", target: "_blank", rel: "noopener noreferrer", href: url }, name),
        componentDidMount && (React.createElement(LIRender, { vanity: vanity, locale: locale, size: size, theme: theme, type: type, entity: entity, version: version, isCreatePage: false, debug: props.debug, cleanUp: props.cleanUp })))) : (React.createElement(LinkedInBadgeSelfRender, { locale: locale, size: size, style: props.style, entity: entity, theme: theme, type: type, vanity: vanity, noCache: noCache, version: version, className: props.className, generateUidWithoutApi: generateUidWithoutApi, hideViewProfileButton: props.hideViewProfileButton, id: props.id, debug: props.debug, name: name, fetchViaReactQuery: useQueryToFetch, isCreatePage: false }, props.children));
};
export default memo(LinkedInBadge);
